;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x1e5d9a7cfb9365b53d0953893e59b55b . "./code.cg2js/cg-status-bar.fasl")
(#xfd3f01906523af5b2b6f75947b531e03 . "./code.cg2js/cg-hotspot.fasl")
(#x01dc6779e62eac93a6c0c11beb750953 . "./code.cg2js/cg-toolbar.fasl")
(#x9e7b8a9224e1ab2ed7b1600b1c93ab19 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xba68b1013dad086614da4464a6393ee8 . "./code.cg2js/cg-tooltip.fasl")
(#x7280505c27230bb876fd9a083b065bae . "./code.cg2js/cg-calendar.fasl")
(#x73566fdbb31e957caba8c08adb88328c . "./code.cg2js/cg-item-list.fasl")
(#xdd7dd7561f7f36c7aeadbd22085579b2 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xca85f276f5f780a713cbe68d731da1d5 . "./code.cg2js/cg-trackbar.fasl")
(#xd13571e6ad79a33f48f83e69a55304b0 . "./code.cg2js/cg-class-grid.fasl")
(#xc0d172c5c25163ab4e1b8391315ffb66 . "./code.cg2js/cg-dialog-item.fasl")
(#xf1cee6f8756f3c48983ccc38db958b09 . "./code.cg2js/cg-comtab.fasl")
(#x7fa8e327e7375617cdd62a390c55167e . "./code.cg2js/cg-lisp-text.fasl")
(#x0e856c163229793157ef979e00207e61 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xed385e3e076020f1d5208c8844a68ec6 . "./code.cg2js/cg-button.fasl")
(#x9876655700670848ff0ac08548a62cad . "./code.cg2js/cg-printing.fasl")
(#x9bbb0547876b6d5064b49c1a81c4f5aa . "./code.cg2js/cg-pixmap-printing.fasl")
(#x52c7e6b0d9894a4004c2d800990a8cdc . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xab0db9e680830395359a2fcaa11d6a68 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xb7cdc38ac56c8ebe06a8f7640e50b266 . "./code.cg2js/cg-selected-object.fasl")
(#xee53efd468c31c712e16c1540f52bc46 . "./code.cg2js/cg-text-or-combo.fasl")
(#xcb57cf0fecc406f38c0bd573a74afc1d . "./code.cg2js/cg-graphics-context.fasl")
(#x3770d0b3a2f5f1daecb0229d9fa9a52b . "./code.cg2js/cg-edit-in-place.fasl")
(#xa918d155407fc5e14eef3179f268e1db . "./code.cg2js/cg-string-dialog.fasl")
(#xa8af3cdd7c2f31977af4b5f12a261fd0 . "./code.cg2js/cg-list-view.fasl")
(#x48596145c826d3b1a695681dadb31541 . "./code.cg2js/cg-intersect.fasl")
(#x973b5da121abaa5d5cebde0f0f558e1e . "./code.cg2js/cg-text-widget.fasl")
(#xf785fa94c5fda53e800ab9767549c926 . "./code.cg2js/cg-directory-dialog.fasl")
(#x79d5e3c7f504872ec2a88136dc9d8239 . "./code.cg2js/cg-file-dialog.fasl")
(#x9db02c7b8d8eae4b641952eb7daba2d3 . "./code.cg2js/cg-dde-utils.fasl")
(#xd586955d04d1f2d91031c2e7d626cd9d . "./code.cg2js/cg-nodes.fasl")
(#xac08df5de1288bd3fc13835ec2ca8878 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xded7294636dfda7d4597f355aa742bdd . "./code.cg2js/cg-up-down-control.fasl")
(#x419c7741f149d751ca9542f94aa8d5b3 . "./code.cg2js/cg-get-position.fasl")
(#x58d086b27f62274c6576f984cb7d73b9 . "./code.cg2js/cg-toggling-widget.fasl")
(#x8c4dd15347fcd82ee1760b196ee6f433 . "./code.cg2js/cg-acache.fasl")
(#x108fe0f650974b6083284eb1379915cc . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x2e455a7d05fb4c507df08fd3eb2a6fcf . "./code.cg2js/cg-base.fasl")
(#x35c7bd9c57db76465073444f615dd5bb . "./code.cg2js/cg-drag-and-drop.fasl")
(#xf0cf380e125d7035eb97a97eec94ee8f . "./code.cg2js/cg-find-string-dialog.fasl")
(#xc5769111d0f74ce692704a8e478995d4 . "./code.cg2js/cg-property.fasl")
(#x44ad2a1772e6f3a7f80f1771770a3afb . "./code.cg2js/cg-editable-text.fasl")
(#x26049599cd2180deef83efc2316809c8 . "./code.cg2js/cg-lamp.fasl")
(#xa882a86be11fc71fa7caeb47be368d4d . "./code.cg2js/cg-progress-indicator.fasl")
(#xcc82ff901420baf42c075ac1d60a95e7 . "./code.cg2js/cg-chart-widget.fasl")
(#xf40ee24bae7acbf448c38b409f52f630 . "./code.cg2js/cg-common-control.fasl")
(#xeca065f077189aa0c5da54d4397c287a . "./code.cg2js/cg-font-dialog.fasl")
(#xc6f824da979326fee39bdc2546f2c89f . "./code.cg2js/cg-gesture-emulation.fasl")
(#xd23df653002a7437c6fa656d7745930f . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x2075fc59bf896c5af3528f00d63ff78f . "./code.cg2js/cg-os-window.fasl")
(#x15ef225c3ffbaca6c460d5c45f9fcf34 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x6f72416b41ece5577b02798136da5448 . "./code.cg2js/cg-pixmap.fasl")
(#x43180202dc30a65fd67bd2a84a3e9e7a . "./code.cg2js/cg-chart-or-plot.fasl")
(#x99b74f2f3b00f7580b6df0d762305733 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x46ed144fa11cabd208ac4eb5020ca865 . "./code.cg2js/cg-scaling-stream.fasl")
(#x4a4c5ee67d308c82cefdffe4736cd89b . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x235386669149aa93293c0e29a2679caa . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x93cc65d1b1b26d040b76ede1dac65392 . "./code.cg2js/cg-timer.fasl")
(#x29bdd87abb255f40eb99a0d64479d9a6 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa574d0c5a583dc303ef584d13b2efe30 . "./code.cg2js/cg-caret.fasl")
(#x4c7fad0ba81390f9919e6703a3d35e45 . "./code.cg2js/cg-template-string.fasl")
(#xc66a1f83bc9da96bd6c2dade28efc407 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xc17f56ef52164dabce89b66d06fdf3d5 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x3e73f5395676c6f6fca2a58f83ae6f44 . "./code.cg2js/cg-rich-edit.fasl")
(#x7ba80f90e020211224368445b0d48353 . "./code.cg2js/cg-combo-box.fasl")
(#xc0733a3824b8061860104fa255fb6659 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xfcbed66befbd5d67f96c84a0e7883959 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x08144faecce4547236af250bb95c1ded . "./code.cg2js/cg-menu-tooltip.fasl")
(#xfdb9164871e7719e501eab723551cc8b . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x8f8104de03f4de74e42a02ef8d8b675c . "./code.cg2js/cg-outline.fasl")
(#x7c6c63471b4d33e5721c448a28d4d89d . "./code.cg2js/cg-class-support.fasl")
(#x2c30d8661ad82ec728585d260d6cb870 . "./code.cg2js/cg-lettered-menu.fasl")
(#x9e58b5e3ebfed3ed6c81e12f04d7d9bf . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x732785cbae6c3f25a73fb38fb567803f . "./code.cg2js/cg-fill-texture.fasl")
(#x87f35acf1aebd8b29b134c8cbd6b3137 . "./code.cg2js/cg-lisp-widget.fasl")
(#x4424a5564fbe5407ba6028078edac2db . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x39e0442231a5590dc7cb9a21b250a8a3 . "./code.cg2js/cg-clipboard.fasl")
(#x2c34e7ff93ef164c9aae6302a11407f7 . "./code.cg2js/cg-wrap-string.fasl")
(#x93a0c4cc97bf2596bdab01c812d70cd6 . "./code.cg2js/cg-os-widget.fasl")
(#xe9a3159ff46b82c77a8a457296292e53 . "./code.cg2js/cg-check-box.fasl")
(#xd679540d0c86f821096c85fcd1d4eee2 . "./code.cg2js/cg-choice-list.fasl")
(#x3bbbf05dd337c9ce3b7aeb72e2fce0c9 . "./code.cg2js/cg-layout.fasl")
(#xcfe06d68a4ccb7ce688515dd429a61c2 . "./code.cg2js/cg-group-box.fasl")
(#x783228c920ef1dc4a08419c306ddab80 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x70c06ba88f5d44db39c417353267fb38 . "./code.cg2js/cg-radio-button.fasl")
(#xf2bb4be2d297a677c7d987b65fa16857 . "./code.cg2js/cg-tab-control.fasl")
(#xb2fa43e247515c96cb164b8eb4301c23 . "./code.cg2js/cg.fasl")
(#xb2cd2e16c32b6d5df908bfde8f2ee1a3 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x2b9601f0870b0abc5972a58512da34bd . "./code.cg2js/cg-dropping-outline.fasl")
(#x386c6385ae3fd69e24dfa6e59a470e45 . "./code.cg2js/cg-get-pixmap.fasl")
(#x96cba76347bbb168ba9d677d5016f3da . "./code.cg2js/cg-grid-widget.fasl")
(#xc15d240d6fda7cc09cab955573fb9cb8 . "./code.cg2js/cg-utility-dialog.fasl")
(#x1e2c9b33a7c20d0b850f055e97499cc6 . "./code.cg2js/cg-static-text.fasl")
(#x1bfc31460309f14237b9b6f43e04bb79 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x8d2eeaaad91011f5f43dfe5a493b300c . "./code.cg2js/cg-object-editor-layout.fasl")
(#x01126c7582ca3965827a86cc859dad8b . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x62b314be6b924c9ade3723b35e100e3c . "./code.cg2js/cg-bitmap-pane.fasl")
(#x020071014447132c4ad36ea4cd4ba6e1 . "./code.cg2js/cg-plot-widget.fasl")
(#x018b434ead238a3fe1f8f712804f4681 . "./code.cg2js/cg-color-dialog.fasl")
(#xf5e20812eecc949bc5c0a5eb74b6a79d . "./code.cg2js/cg-icon-pixmap.fasl")
(#xf409210ebe341e7d531e64207f1bd7e5 . "./code.cg2js/cg-icon.fasl")
(#x40f07c5c6cf5cba970a04e6887e9f7d4 . "./code.cg2js/cg-dev.fasl")
(#x642ce1b884df8eca7e10893896c778e3 . "./code.cg2js/cg-choose-printer.fasl")
(#x14d143c6649ed49750a3692a4aff933e . "./code.cg2js/cg-intersect-posbox.fasl")
(#xf7724f8d952b8ba00f9fb0c532e87d4c . "./code.cg2js/cg-menu.fasl")
(#xebc41179cee39b6b28f3f6484fdbc08f . "./code.cg2js/cg-yes-no-list.fasl")
(#x9686a44db16a2f89947a4c437511f793 . "./code.cg2js/cg-palette.fasl")
(#x742de6c331d3cd149d2aa6db701c1c29 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x107bfb3251c2054beab59636058d68ac . "./code.cg2js/cg-message-dialog.fasl")
(#xc60185f8991850317cb9f44402782df0 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x0267398d4f7422f15252ce889ece8a8e . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x89df2a9ac12517b220e8d76b37ffbd08 . "./code.cg2js/cg-split-bar.fasl")
(#x89a46984648695bd7d3d9e5335276533 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x9019db2fbcc51c990381a215caf4edc6 . "./code.cg2js/cg-web-browser.fasl")
(#xc18e88cf22c80ffa666fef5642a42ffc . "./code.cg2js/cg-project-window.fasl")
(#x2b6329457087b0b6189e2c0b4daea30f . "./code.cg2js/cg-picture-widget.fasl")
(#x5a6e6a92595d1413939c838102cd7f7f . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xce396dfb24b25d95381c6d8bf65a6207 . "./code.cg2js/cg-object-editor.fasl")
(#x0fc1849765199df929ea153201cea230 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x66690ea05067bd5af4c1413eea6baf05 . "./code.cg2js/cg-paren-matching.fasl")
(#xb2f0c47b28622719c808a92323c8f8fd . "./code.cg2js/cg-sample-file-menu.fasl")
(#x3a32163be652d7304ffcad93fa18d3a1 . "./code.cg2js/cg-drawable.fasl")
(#x8829f7f460691ea88146e024979a82a2 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x5e7b438a2d6088a9ccb7ba662c1cf4ef . "./code.cg2js/cg-html-widget.fasl")
(#xca36bd1f25833206e0fec12c6bdcf555 . "./code.cg2js/cg-curve.fasl")
(#x7ed6e3d91340ad9c5e148b07384fe214 . "./code.cg2js/cg-yes-no-string.fasl")
(#xd8a4c3e0964769cae6dc11cf1ac8a388 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x15b2c5a30d815f4b780caec42a54af53 . "./code.cg2js/cg-html-dialog.fasl")
(#xf4232025c17f6a71b88313ab228b6846 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xa7da5fe13fd8388462593e64862bbeb4 . "./code.cg2js/cg-tray.fasl")
(#xb499a1c9b93ee8ddd95087e41e3054eb . "./code.idejs/ide-apropos.fasl")
(#xa28b710e0d14788e2ad4ea5095e95edc . "./code.idejs/ide-window-list.fasl")
(#x68d5511f8af0db01b4b8b7a67ca1c9b7 . "./code.idejs/ide-class-browser.fasl")
(#xaddbd40927589f23dd19e855a8aee0f7 . "./code.idejs/ide-base.fasl")
(#xfef4a905bcbe90e4312f1b5bc0a174d6 . "./code.idejs/ide-process-browser.fasl")
(#x86d2e5c88e4f1ad108ce0bf1057baab8 . "./code.idejs/ide-acache.fasl")
(#x4429deff9f68e2ef220f3ee9478454ad . "./code.idejs/ide-navigator.fasl")
(#x2b7784c2530d71c6c1a5d4894b19e70b . "./code.idejs/ide-trace.fasl")
(#x2a8a74cb47e7a9269901d3911acee627 . "./code.idejs/ide-project.fasl")
(#x335a6174eac8ee6b9001172250a7b236 . "./code.idejs/ide-patch-dialog.fasl")
(#x4286a4f333e0c2c3a117e86501593978 . "./code.idejs/ide-grapher.fasl")
(#xd5c201e9a74ca4228a8a5c6fd9b4eef0 . "./code.idejs/ide-dev.fasl")
(#xd6697ae1c63a23fbe9688c0004b5b35f . "./code.idejs/ide-keyshort.fasl")
(#xe6d406a8412fabbae418576ba09bf226 . "./code.idejs/ide-editor.fasl")
(#xd4406b82f908c1a87613ab097269b87b . "./code.idejs/ide-inspector.fasl")
(#xa6ca8cf3615f67eb9aa2ab0122c7faf1 . "./code.idejs/ide.fasl")
(#xc21514cadd78e2797c8cef94721d1614 . "./code.idejs/ide-clipboard.fasl")
(#x95ec438b709afe9176b976ce6d062072 . "./code.idejs/ide-find-definitions.fasl")
(#x41b470b6f67b3f56dfcb642a2795d59e . "./code.idejs/ide-form.fasl")
(#x83e4191a96939920a9dd7ab291e1198c . "./code.idejs/ide-intro.fasl")
(#x3d64df06f014289686d6b0ded7626f8e . "./code.idejs/ide-find-in-files.fasl")
(#x5c724330c749807e059c99f6ec0e55f7 . "./code.idejs/ide-package-list.fasl")
(#x5d46ed13c7a7b0db07d35f448973f036 . "./code.idejs/ide-class-grapher.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
